@@ -3,13 +3,15 @@ package Log::Saftpresse::Plugin::Amavis;
 use Moose;
 
 # ABSTRACT: plugin to parse amavisd-new logs
-our $VERSION = '1.3'; # VERSION
+our $VERSION = '1.4'; # VERSION
 
 
 extends 'Log::Saftpresse::Plugin';
 
 with 'Log::Saftpresse::Plugin::Role::CounterUtils';
+with 'Log::Saftpresse::Plugin::Role::Tracking';
 
+use Log::Saftpresse::Log4perl;
 use JSON;
 
 has 'json' => (
@@ -20,7 +22,7 @@ has 'json' => (
 has 'test_stats' => ( is => 'ro', isa => 'Bool', default => 1 );
 
 sub process {
-	my ( $self, $stash ) = @_;
+	my ( $self, $stash, $notes ) = @_;
 	my $program = $stash->{'program'};
 	if( ! defined $program || $program ne 'amavis' ) {
 		return;
@@ -37,7 +39,10 @@ sub process {
 		eval {
 			$json_data = $self->json->decode( $stash->{'message'} );
 		};
-		if( $@ ) { return; }
+		if( $@ ) {
+      $log->warn('error while parsing amavis JSON log message: '.$@);
+      return;
+    }
 		if( ref($json_data) ne 'HASH' ) {
 			return;
 		}
@@ -48,6 +53,14 @@ sub process {
 		return;
 	}
 
+  $self->get_tracking_id('queue_id', $stash, $notes);
+  if( defined $stash->{'queued_as'}
+      && ref($stash->{'queued_as'}) eq 'ARRAY' ) {
+    foreach my $queued_as_id ( @{$stash->{'queued_as'}} ) {
+      $self->set_tracking_id('queue_id', $stash, $notes, $queued_as_id);
+    }
+  }
+
 	$self->incr_host_one($stash, 'total' );
 	$self->count_fields_occur( $stash, 'content_type' );
 	$self->count_array_field_values( $stash, 'action' );
@@ -74,7 +87,7 @@ Log::Saftpresse::Plugin::Amavis - plugin to parse amavisd-new logs
 
 =head1 VERSION
 
-version 1.3
+version 1.4
 
 =head1 Description
 
