@@ -3,7 +3,7 @@ package Log::Saftpresse::Plugin::Postfix;
 use Moose;
 
 # ABSTRACT: plugin to parse analyse postfix logging
-our $VERSION = '1.3'; # VERSION
+our $VERSION = '1.4'; # VERSION
 
 
 extends 'Log::Saftpresse::Plugin';
@@ -28,6 +28,7 @@ has 'verp_mung' => ( is => 'rw', isa => 'Int', default => 0 );
 has 'tls_stats' => ( is => 'rw', isa => 'Bool', default => 1 );
 
 with 'Log::Saftpresse::Plugin::Role::CounterUtils';
+with 'Log::Saftpresse::Plugin::Role::Tracking';
 
 with 'Log::Saftpresse::Plugin::Postfix::Service';
 with 'Log::Saftpresse::Plugin::Postfix::QueueID';
@@ -48,6 +49,9 @@ sub process {
 	if( ! defined $program || $program !~ /^postfix\// ) {
 		return;
 	}
+
+  $self->get_tracking_id('pid', $stash, $notes);
+
 	$self->process_service( $stash, $notes );
 	if( ! defined $stash->{'service'} ) {
 		return;
@@ -81,7 +85,7 @@ Log::Saftpresse::Plugin::Postfix - plugin to parse analyse postfix logging
 
 =head1 VERSION
 
-version 1.3
+version 1.4
 
 =head1 Description
 
