@@ -3,15 +3,16 @@ package Log::Saftpresse::Plugin::Postfix::QueueID;
 use Moose::Role;
 
 # ABSTRACT: plugin to parse the postfix queue ID
-our $VERSION = '1.3'; # VERSION
+our $VERSION = '1.4'; # VERSION
 
 sub process_queueid {
-	my ( $self, $stash ) = @_;
+	my ( $self, $stash, $notes ) = @_;
 	
 	if( my ( $queue_id, $msg ) = $stash->{'message'} =~
 			/^([A-Z0-9]{8,12}|[b-zB-Z0-9]{15}|NOQUEUE): (.+)$/) {
 		$stash->{'queue_id'} = $queue_id;
 		$stash->{'message'} = $msg;
+    $self->get_tracking_id('queue_id', $stash, $notes);
 	}
 
 	return;
@@ -31,7 +32,7 @@ Log::Saftpresse::Plugin::Postfix::QueueID - plugin to parse the postfix queue ID
 
 =head1 VERSION
 
-version 1.3
+version 1.4
 
 =head1 AUTHOR
 
