@@ -3,7 +3,7 @@ package Log::Saftpresse::Plugin::Postfix::Recieved;
 use Moose::Role;
 
 # ABSTRACT: plugin to gather postfix recieved messages statistics
-our $VERSION = '1.3'; # VERSION
+our $VERSION = '1.4'; # VERSION
 
 use Log::Saftpresse::Plugin::Postfix::Utils qw( postfix_remote );
 
@@ -23,6 +23,12 @@ sub process_recieved {
 			$self->incr_per_time_one( $stash );
 		}
 		$notes->set('client-'.$qid => $host);
+    if( $message =~ /orig_queue_id=(.+?)(,|$)/) {
+      $stash->{'orig_queue_id'} = $1;
+      $self->get_tracking_id('queue_id', $stash, $notes, $1);
+      $self->set_tracking_id('pid', $stash, $notes);
+    }
+    $self->set_tracking_id('queue_id', $stash, $notes);
 	} elsif( $service eq 'pickup' &&
 			$message =~ /(sender|uid)=/ ) {
 		$self->incr_host_one( $stash, 'incoming', 'total');
@@ -30,6 +36,7 @@ sub process_recieved {
 			$self->incr_per_time_one( $stash );
 		}
 		$notes->set('client-'.$qid => 'pickup');
+    $self->set_tracking_id('queue_id', $stash, $notes);
 	}
 
 	return;
@@ -59,7 +66,7 @@ Log::Saftpresse::Plugin::Postfix::Recieved - plugin to gather postfix recieved m
 
 =head1 VERSION
 
-version 1.3
+version 1.4
 
 =head1 AUTHOR
 
